(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9099,        316]*)
(*NotebookOutlinePosition[      9754,        339]*)
(*  CellTagsIndexPosition[      9710,        335]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Supposons que nous mesurions la p\[EAcute]riode d'un pendule ",
  StyleBox["T",
    FontSlant->"Italic"],
  " en fonction de la longueur. Cette p\[EAcute]riode, si nous supposons que \
l'amplitude est faible, ne d\[EAcute]pend pas de l'angle initial et elle est \
donn\[EAcute]e par:"
}], "Subtitle"],

Cell[BoxData[
    \(TraditionalForm\`T\  = 2\ \[Pi]\ \@\(l\/g\)\)], "Input",
  FontSize->18]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
o\[UGrave] l est la longueur du pendule et g l'acc\[EAcute]l\
\[EAcute]ration du lieu. Nous aimerions ensuite calculer g (acc\[EAcute]l\
\[EAcute]ration du lieu). La valeur de g s'exprime par :\
\>", "Subtitle"],

Cell[BoxData[
    FormBox[
      StyleBox[\(g = \(4\ l\ \[Pi]\^2\)\/T\^2\),
        FontSize->36], TraditionalForm]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Cette expression permet de calculer ",
  StyleBox["g",
    FontSlant->"Italic"],
  " \[AGrave] partir des mesures de ",
  StyleBox["l",
    FontSlant->"Italic"],
  " et de ",
  StyleBox["T",
    FontSlant->"Italic"],
  ". Ces mesures comportent des incertitudes que nous d\[EAcute]signerons par \
",
  StyleBox["\[CapitalDelta]l",
    FontSlant->"Italic"],
  " et ",
  StyleBox["\[CapitalDelta]T. ",
    FontSlant->"Italic"],
  "Le but du calcul d'incertitude est de trouver comment ces incertitudes \
affectent le r\[EAcute]sultat du calcul afin de le donner sous la forme ",
  StyleBox["g",
    FontSlant->"Italic"],
  " \[PlusMinus] ",
  StyleBox["\[CapitalDelta]g. ",
    FontSlant->"Italic"],
  "Pour calculer cette incertitude, nous d\[EAcute]finissons la fonction qui \
permet de calculer ",
  StyleBox["g",
    FontSlant->"Italic"],
  " :"
}], "Subtitle"],

Cell[BoxData[
    RowBox[{
      StyleBox[\(g[l_, T_]\),
        FontSize->18], 
      StyleBox[":=",
        FontSize->18], \(\(4  l\ \[Pi]\^2\)\/T\^2\)}]], "Input",
  FontSize->48]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Remarques\n1. Ne pas oublier ",
  StyleBox["les soulign\[EAcute]s",
    FontColor->RGBColor[0, 0, 1]],
  " dans le membre de gauche lorsque vous d\[EAcute]finissez une fonction\n2. \
Utiliser le ",
  StyleBox[":=",
    FontColor->RGBColor[0, 0, 1]],
  " entre les deux membres (affectation diff\[EAcute]r\[EAcute]e)\n\nPour \
trouver l'incertitude sur ",
  StyleBox["g",
    FontSlant->"Italic"],
  ", nous d\[EAcute]rivons cette fonction par rapport \[AGrave] chaque \
variable et prendre la valeur absolue du r\[EAcute]sultat :"
}], "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[D[g[l, T], l]] + Abs[D[g[l, T], T]]\)], "Input",
  FontSize->16],

Cell[BoxData[
    \(8\ \[Pi]\^2\ Abs[l\/T\^3] + \(4\ \[Pi]\^2\)\/Abs[T]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pour obtenir l'incertitude ",
  StyleBox["\[CapitalDelta]g",
    FontSlant->"Italic"],
  " sur ",
  StyleBox["g",
    FontSlant->"Italic"],
  ", nous devons multiplier chaque d\[EAcute]riv\[EAcute]e partielle par \
l'incertitude qui affecte la variable par rapport \[AGrave] laquelle nous \
avons d\[EAcute]riv\[EAcute] :"
}], "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[D[g[l, T], l]]*\[CapitalDelta]l + 
      Abs[D[g[l, T], T]]*\[CapitalDelta]T\)], "Input"],

Cell[BoxData[
    \(8\ \[Pi]\^2\ \[CapitalDelta]T\ Abs[
          l\/T\^3] + \(4\ \[Pi]\^2\ \[CapitalDelta]l\)\/Abs[T]\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exemple d'application", "Subtitle"],

Cell[TextData[{
  "La mesure de la p\[EAcute]riode s'effectue \[AGrave] la pr\[EAcute]cision \
du ",
  Cell[BoxData[
      \(TraditionalForm\`10\^e\)]],
  " de seconde et la longueur du pendule \[AGrave] 2 mm pr\[EGrave]s. Que \
vaut l'incertitude sur ",
  StyleBox["g",
    FontSlant->"Italic"],
  " ?\nComment cette incertitude varie-t-elle si on double l'incertitude sur \
",
  StyleBox["l",
    FontSlant->"Italic"],
  " et sur ",
  StyleBox["T",
    FontSlant->"Italic"],
  " ?\nLe pendule \[AGrave] une longueur de 40 cm et une p\[EAcute]riode de \
1.27 s"
}], "Subtitle"],

Cell["Entrons ces donn\[EAcute]es num\[EAcute]riques dans une liste", \
"Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dn = {l \[Rule] 0.4, \[CapitalDelta]l \[Rule]  .002, 
        T \[Rule] 1.27, \[CapitalDelta]T \[Rule]  .1}\)], "Input",
  FontSize->18],

Cell[BoxData[
    \({l \[Rule] 0.4`, \[CapitalDelta]l \[Rule] 0.002`, 
      T \[Rule] 1.27`, \[CapitalDelta]T \[Rule] 0.1`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Attention aux unit\[EAcute]s, utilisez les unit\[EAcute]s du SI (m, kg, \
s)", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[D[g[l, T], l]]*\[CapitalDelta]l + 
        Abs[D[g[l, T], T]]*\[CapitalDelta]T /. dn\)], "Input"],

Cell[BoxData[
    \(1.5907906817541755`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[ .4, 1.27]\)], "Input"],

Cell[BoxData[
    \(9.790667147214938`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Le r\[EAcute]sultat s'\[EAcute]crira donc 9.79 \[PlusMinus] 1.59 ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[
            StyleBox["m",
              FontSlant->"Plain"], 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], "2"]],
          FontSlant->"Italic"], TraditionalForm]]]
}], "Subtitle"],

Cell[TextData[{
  "Le moment d'inertie d'un cylindre creux peut se calculer de la mani\
\[EGrave]re suivante : on calcule le moment d'inertie du cylindre plein et on \
d\[EAcute]duit l'inertie du cylindre qui correspond \[AGrave] la partie \
\[EAcute]vid\[EAcute]e. Pour ce calcul, nous utilisons les valeurs mesur\
\[EAcute]es suivantes:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_ext\[EAcute]rieur\)]],
  " (diam\[EGrave]tre ext\[EAcute]rieur)\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_int\[EAcute]rieur\)]],
  " (diam\[EGrave]tre int\[EAcute]rieur)\n",
  StyleBox["l",
    FontSlant->"Italic"],
  " \t(longueur du cylindre)\n\[Rho]\t(masse volumique de la mati\[EGrave]re)\
\n\nDevoirs pour la rentr\[EAcute]e\n\n1. Exprimez le moment d'inertie \
\[AGrave] partir de ces grandeurs\n2. Ecrivez l'expression ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " qui permet d'obtenir l'incertitude sur ce moment d'inertie (dans spip \
entre des balises <cadre>\[Ellipsis]</cadre> pour pouvoir copier coller dans \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " d\[EGrave]s votre retour (pour le 26 janvier au plus tard) lors du contr\
\[OHat]le de devoirs.\n\n",
  StyleBox["3. Calculez ce moment d'inertie et l'incertitude qui l'affecte \
pour les valeurs suivantes :",
    FontColor->GrayLevel[0.500008]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_ext\[EAcute]rieur\)],
    FontSize->36],
  "= 5 cm",
  StyleBox["\n",
    FontSize->36],
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_int\[EAcute]rieur\)],
    FontSize->36],
  StyleBox[" ",
    FontSize->36],
  StyleBox["= ",
    FontSize->18],
  "4.5 cm",
  "\n",
  StyleBox["l",
    FontSlant->"Italic"],
  " = 20 cm\n\[Rho] = 2.7 kg/d",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["m",
            FontSlant->"Plain"], "3"], TraditionalForm]]],
  "\n"
}], "Subtitle"]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 1440}, {0, 825}},
WindowSize->{991, 791},
WindowMargins->{{122, Automatic}, {1, Automatic}},
Magnification->2
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 319, 7, 370, "Subtitle"],
Cell[2098, 62, 92, 2, 135, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2227, 69, 221, 4, 270, "Subtitle"],
Cell[2451, 75, 126, 3, 207, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2614, 83, 882, 29, 570, "Subtitle"],
Cell[3499, 114, 182, 6, 247, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3718, 125, 565, 14, 620, "Subtitle"],

Cell[CellGroupData[{
Cell[4308, 143, 88, 2, 60, "Input"],
Cell[4399, 147, 88, 1, 89, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4536, 154, 357, 10, 270, "Subtitle"],

Cell[CellGroupData[{
Cell[4918, 168, 113, 2, 53, "Input"],
Cell[5034, 172, 135, 2, 89, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5218, 180, 41, 0, 120, "Subtitle"],
Cell[5262, 182, 578, 18, 470, "Subtitle"],
Cell[5843, 202, 83, 1, 170, "Subtitle"],

Cell[CellGroupData[{
Cell[5951, 207, 156, 3, 109, "Input"],
Cell[6110, 212, 138, 2, 53, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6297, 220, 96, 1, 170, "Subtitle"],

Cell[CellGroupData[{
Cell[6418, 225, 121, 2, 53, "Input"],
Cell[6542, 229, 53, 1, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6632, 235, 45, 1, 53, "Input"],
Cell[6680, 238, 52, 1, 53, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6781, 245, 387, 12, 128, "Subtitle"],
Cell[7171, 259, 1912, 54, 1820, "Subtitle"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

